ajdmom.cpp\_mom
===============

.. automodule:: ajdmom.cpp_mom

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      cmcpp
      d1_times_key
      decode
      dmgf
      dmgf_cpp
      dterm
      mcpp
      mcpp_original
      mnorm
   
   

   
   
   

   
   
   



